﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Monnit.Mine;

namespace SampleMineApplication
{
    public partial class MineGateway : Form
    {
        private Gateway _Gateway;

        public MineGateway(Gateway gateway)
        {
            InitializeComponent();

            _Gateway = gateway;
        }

        private void MineGateway_Load(object sender, EventArgs e)
        {
            if (_Gateway == null)
            {
                MessageBox.Show("Gateway is null");
                this.Close();
            }
            txtGatewayID.Text = _Gateway.GatewayID.ToString();
            txtGatewayType.Text = _Gateway.GatewayType.ToString();
            txtGatewayFirmware.Text = _Gateway.GatewayFirmwareVersion;
            txtRadioFirmware.Text = _Gateway.RadioFirmwareVersion;

            txtHost.Text = _Gateway.ServerHostAddress;
            txtPort.Text = _Gateway.Port.ToString();
            txtReportInterval.Text = _Gateway.ReportInterval.ToString();

            if (_Gateway.GatewayType == BaseApplication.eGatewayType.Ethernet_3_0)
            {
                cbUseDHCP.Checked = _Gateway.GatewayIP == "0.0.0.0";
                cbUseDHCP_CheckedChanged(cbUseDHCP, null);

                txtIPAddress.Text = _Gateway.GatewayIP;
                txtSubnet.Text = _Gateway.GatewaySubnet;
                txtDefaultRouter.Text = _Gateway.DefaultRouterIP;
                txtPrimaryDNS.Text = _Gateway.GatewayDNS;
                txtSecondaryDNS.Text = _Gateway.SecondaryDNS;
            }
            else
            {
                cbUseDHCP.Visible = false;
                pnlStaticIP.Visible = false;
                boxConfiguration.Height = 133;
                this.Height = 271;
                txtIPAddress.Text = "0.0.0.0";
            }

            cbSendConfiguration.Checked = _Gateway.IsDirty;
        }

        private void cbUseDHCP_CheckedChanged(object sender, EventArgs e)
        {
            if (cbUseDHCP.Checked)
            {
                pnlStaticIP.Visible = false;
                boxConfiguration.Height = 163;
                this.Height = 301;
                txtIPAddress.Text = "0.0.0.0";
            }
            else{
                this.Height = 434;
                boxConfiguration.Height = 296;
                pnlStaticIP.Visible = true;
            }
        }

        private void btnUpdate_Click(object sender, EventArgs e)
        {
            string Host = txtHost.Text;
            UInt16 Port = 0;
            int ReportInterval = 0;

            IPAddress temp;
            string StaticIP = txtIPAddress.Text;
            string Subnet = txtSubnet.Text;
            string DefaultRouter = txtDefaultRouter.Text;
            string PrimaryDNS = txtPrimaryDNS.Text;
            string SecondaryDNS = txtSecondaryDNS.Text;

            try
            {
                if(string.IsNullOrEmpty(Host))
                    throw new Exception("Invalid Host");
                if (!UInt16.TryParse(txtPort.Text, out Port))
                    throw new Exception("Invalid Port");
                if (!Int32.TryParse(txtReportInterval.Text, out ReportInterval))
                    throw new Exception("Invalid Report Interval");

                //Use DHCP
                if (StaticIP == "0.0.0.0")
                {
                    Subnet = "0.0.0.0";
                    DefaultRouter = "0.0.0.0";
                    PrimaryDNS = "0.0.0.0";
                    SecondaryDNS = "0.0.0.0";
                }
                else
                {
                    if (!IPAddress.TryParse(StaticIP, out temp))
                        throw new Exception("Invalid Static IP Address");
                    if (!IPAddress.TryParse(Subnet, out temp))
                        throw new Exception("Invalid Subnet Mask");
                    if (!IPAddress.TryParse(DefaultRouter, out temp))
                        throw new Exception("Invalid Default Router");
                    if (!IPAddress.TryParse(PrimaryDNS, out temp))
                        throw new Exception("Invalid Primary DNS");
                    if (!IPAddress.TryParse(SecondaryDNS, out temp))
                        throw new Exception("Invalid Secondary DNS");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
                return;
            }
            _Gateway.UpdateServerInformation(Host, Port);
            _Gateway.UpdateReportInterval(ReportInterval);
            _Gateway.UpdateGatewayIP(StaticIP, Subnet, DefaultRouter, PrimaryDNS, SecondaryDNS);

            MineGateway_Load(this, null);
        }
    }
}
